# About

This is a personal collection of Python and IDL routines for my research
in Space Plasma Physics, organized into packages. Some are more
well-documented than others. Please use them at your discretion.

## Installation

The Python codes are published on PyPI. For installation run
```
pip install tvolib
```

To use the IDL code, run
```
source bin/init_idl.sh
```
to put `src/idl` into `IDL_PATH`.
